@@ -1,3 +1,5 @@
+# remove when we don't support py38 anymore
+from __future__ import annotations
 import argparse
 import logging
 
@@ -8,12 +10,12 @@ from dotenv_cli import __VERSION__
 logger = logging.getLogger(__name__)
 
 
-def parse_args(args=None):
+def parse_args(args: list[str] | None = None) -> argparse.Namespace:
     """Parse arguments.
 
     Paramters
     ---------
-    args : list[str]
+    args
         This if for debugging only.
 
     Returns
@@ -45,7 +47,7 @@ def parse_args(args=None):
     return parser.parse_args(args)
 
 
-def main():
+def main() -> int:
     """Run dotenv.
 
     This function parses sys.argv and runs dotenv.
@@ -58,6 +60,6 @@ def main():
     """
     args = parse_args()
     if not args.command:
-        return
+        return 0
 
     return run_dotenv(args.dotenv, args.command)
